# Generated by ariadne-codegen on 2023-11-05 09:01
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .fragments import SubscriptionFragment


class ApplySubscription(BaseModel):
    apply_subscription: "ApplySubscriptionApplySubscription" = Field(
        alias="applySubscription"
    )


class ApplySubscriptionApplySubscription(BaseModel):
    subscription: Optional["ApplySubscriptionApplySubscriptionSubscription"]


class ApplySubscriptionApplySubscriptionSubscription(SubscriptionFragment):
    pass


ApplySubscription.update_forward_refs()
ApplySubscriptionApplySubscription.update_forward_refs()
ApplySubscriptionApplySubscriptionSubscription.update_forward_refs()
