# Generated by ariadne-codegen on 2023-11-05 09:01
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ReportEvent(BaseModel):
    report_event: Optional[str] = Field(alias="reportEvent")


ReportEvent.update_forward_refs()
